import jQuery from "jquery";
import { Graph } from "../../graph";
import { CONTEXT } from "../../state";
import { state } from "../../editor";
import ToolMenu from "./toolmenu";

export const COLLECTION_KEY = "collection";

const SELECTED_ITEMS_ID = "#selected-items";
const CLEAR_BUTTON_ID = "#clear-collection";

const CONTEXT_NODE = "#nodes-selected";

const HIDDEN_CLASS = "hidden";

const DOM_LIST_ITEM = "li";

export class CollectMenu extends ToolMenu {
    constructor() {
        super();
        this.context = undefined;
    }

    hookClearButton() {
        // On button press: Notify tool about clearing and empty list
        jQuery(CLEAR_BUTTON_ID).on("click", (e) => {
            this.notifyTool(COLLECTION_KEY, undefined);
        });
    }

    onMenuShow(initial) {
        if (initial) {
            this.hookClearButton();
        }
    }

    afterSet(key, value) {
        if (key === COLLECTION_KEY) {
            this.fillDomList(SELECTED_ITEMS_ID, value, this.itemListRenderer);

            // Set corresponding context
            this.setContext(state.itemsContext);
        }
    }

    itemListRenderer(item) {
        return (
            "<" +
            DOM_LIST_ITEM +
            ">" +
            Graph.toStr(item) +
            "</" +
            DOM_LIST_ITEM +
            ">"
        );
    }

    fillDomList(listId, items, itemRenderer) {
        var listCont = this.find(listId);
        listCont.empty();

        items.forEach((i) => listCont.append(itemRenderer(i)));
    }

    setContext(context) {
        if (context === this.context) {
            return; // Only do something if it changes
        }

        // Disable previous context
        var dom = this.getDomToContext(this.context);
        if (dom !== undefined) {
            dom.addClass(HIDDEN_CLASS);
        }

        // Store and activate new context
        this.context = context;
        dom = this.getDomToContext(this.context);
        if (dom !== undefined) {
            dom.removeClass(HIDDEN_CLASS);
        }
    }

    getDomToContext(context) {
        if (context === undefined) {
            return undefined;
        }

        if (context === CONTEXT.node) {
            return this.find(CONTEXT_NODE);
        } else {
            return undefined;
        }
    }
}
